pub enum ConsumerRebalanceEvent {
Revoked(Vec<TopicPartition>),
Assigned(Vec<TopicPartition>),
Lost(Vec<TopicPartition>),
}Expand description
Consumer rebalance notification.
Variants
Revoked(Vec<TopicPartition>)
Partitions were revoked before being removed from the active assignment.
Assigned(Vec<TopicPartition>)
Partitions were added to the active assignment.
Lost(Vec<TopicPartition>)
Partitions were lost and should not be committed by the callback.
Implementations
Sourceimpl ConsumerRebalanceEvent
impl ConsumerRebalanceEvent
Sourcepub fn partitions(&self) -> &[TopicPartition]
pub fn partitions(&self) -> &[TopicPartition]
Returns the affected partitions.