pub enum TransactionStateError {
Show 13 variants
AlreadyInProgress,
Completing(&'static str),
MustAbortBeforeReuse(String),
Fatal(String),
AppendWithoutBegin,
SendOffsetsWithoutBegin,
AbortRequired(String),
CommitRequiresAbort(String),
NoActiveTransaction,
ShutdownWithActiveTransaction,
ShutdownWhileCompleting(&'static str),
ShutdownAbortRequired(String),
ShutdownFatal(String),
}Expand description
Errors raised by the producer transaction state machine.
Variants
AlreadyInProgress
A transaction is already open.
Completing(&'static str)
The transaction is already completing.
MustAbortBeforeReuse(String)
The transaction must be aborted before it can be used again.
Fatal(String)
The transaction is permanently failed.
AppendWithoutBegin
Records were sent before a transaction was started.
SendOffsetsWithoutBegin
Offsets were sent before a transaction was started.
AbortRequired(String)
The transaction needs an abort before more work can happen.
CommitRequiresAbort(String)
The transaction cannot be committed and must be aborted.
NoActiveTransaction
There is no active transaction to finish.
ShutdownWithActiveTransaction
Shutdown found an active transaction.
ShutdownWhileCompleting(&'static str)
Shutdown found a transaction completion in progress.
ShutdownAbortRequired(String)
Shutdown found a failed transaction that still needs aborting.
ShutdownFatal(String)
Shutdown found a fatal transaction error.