pub enum ValidationError {
EmptyTopicName {
operation: &'static str,
},
MissingTopic {
operation: &'static str,
},
NegativePartition {
operation: &'static str,
partition: i32,
},
EmptyResourceName {
resource: &'static str,
},
InvalidAclResourceType {
resource_type: String,
},
InvalidAclPatternType {
pattern_type: String,
},
EmptyAclPrincipal,
EmptyAclHost,
InvalidAclOperation {
operation: String,
},
InvalidAclPermissionType {
permission_type: String,
},
EmptyConsumerGroupId,
EmptyFeatureName,
}Expand description
Errors raised while validating public API inputs.
Variants
EmptyTopicName
A topic name was empty after trimming.
MissingTopic
A message did not provide a topic and no default topic was configured.
NegativePartition
A partition was negative.
Fields
EmptyResourceName
A resource name was empty after trimming.
InvalidAclResourceType
An ACL resource type cannot be used in a concrete ACL binding.
InvalidAclPatternType
An ACL pattern type cannot be used in a concrete ACL binding.
EmptyAclPrincipal
An ACL principal was empty after trimming.
EmptyAclHost
An ACL host was empty after trimming.
InvalidAclOperation
An ACL operation cannot be used in a concrete ACL binding.
InvalidAclPermissionType
An ACL permission type cannot be used in a concrete ACL binding.
EmptyConsumerGroupId
A consumer group id was empty after trimming.
EmptyFeatureName
A finalized feature name was empty after trimming.