pub enum AdminError {
EmptyTopicName,
InvalidPartitionCount {
partitions: i32,
},
InvalidReplicationFactor {
replication_factor: i16,
},
}Expand description
Errors raised before or during admin operations.
Variants
EmptyTopicName
A topic name was empty.
InvalidPartitionCount
A topic was requested with an invalid partition count.
InvalidReplicationFactor
A topic was requested with an invalid replication factor.