pub enum BrokerError {
Response {
operation: &'static str,
resource: String,
code: i16,
name: String,
retriable: bool,
fatal: bool,
transaction_abort_required: bool,
},
}Expand description
Kafka broker error returned in a response payload.
Variants
Implementations
Sourceimpl BrokerError
impl BrokerError
Sourcepub fn response(
operation: &'static str,
resource: impl Into<Option<String>>,
error: ResponseError,
) -> Self
pub fn response( operation: &'static str, resource: impl Into<Option<String>>, error: ResponseError, ) -> Self
Builds a broker-response error from a Kafka protocol error.
Sourcepub fn fatal(self) -> Self
pub fn fatal(self) -> Self
Marks this broker error as fatal to the current client or transaction.
Sourcepub fn transaction_abort_required(self) -> Self
pub fn transaction_abort_required(self) -> Self
Marks this broker error as requiring transaction abort before reuse.