ConsumerError

Enum ConsumerError 

pub enum ConsumerError {
Show 17 variants ThreadStoppedBefore { operation: &'static str, }, ThreadStoppedDuring { operation: &'static str, }, Join(JoinError), EmptySubscription, EmptySubscriptionPattern, InvalidSubscriptionRegex { message: String, }, ConcurrentPoll, Wakeup, InvalidSeekOffset { offset: i64, }, EmptyTopicPartition, PartitionNotAssigned { operation: &'static str, topic: String, partition: i32, }, InvalidRegularExpression { message: String, }, UnsupportedAssignor { assignor: String, message: String, }, UnreleasedInstanceId { instance_id: String, message: String, }, FencedInstanceId { instance_id: String, message: String, }, ShuttingDown, Fatal { message: String, },
}
Errors raised by the consumer API.

Variants



ThreadStoppedBefore

The runtime stopped before the operation was sent.

Fields

operation: &'static str

Operation that was waiting to be sent.



ThreadStoppedDuring

The runtime stopped while the operation was waiting for a reply.

Fields

operation: &'static str

Operation that was in flight.



Join(JoinError)

The background consumer task could not be joined.



EmptySubscription

A subscription was requested without any topic names.



EmptySubscriptionPattern

A regex subscription was requested with an empty pattern.



InvalidSubscriptionRegex

A regex subscription could not be compiled locally.

Fields

message: String

Regex parser error message.



ConcurrentPoll

Another poll call was already active.



Wakeup

A blocking poll was interrupted with wakeup.



InvalidSeekOffset

A seek offset was negative.

Fields

offset: i64

Requested offset.



EmptyTopicPartition

A topic partition had an empty topic name.



PartitionNotAssigned

The operation needs a partition currently assigned to this consumer.

Fields

operation: &'static str

Operation that needed the assignment.

topic: String

Topic name.

partition: i32

Partition number.



InvalidRegularExpression

The broker rejected the subscription regex.

Fields

message: String

Broker error message.



UnsupportedAssignor

The broker rejected the configured server-side assignor.

Fields

assignor: String

Requested assignor name.

message: String

Broker error message.



UnreleasedInstanceId

A static member id is still owned by another consumer instance.

Fields

instance_id: String

Static member instance id.

message: String

Broker error message.



FencedInstanceId

The broker fenced this static member instance.

Fields

instance_id: String

Static member instance id.

message: String

Broker error message.



ShuttingDown

The consumer runtime is already shutting down.



Fatal

The consumer runtime is in a fatal state.

Fields

message: String

Fatal state reason.