ProducerError

Enum ProducerError 

pub enum ProducerError {
Show 23 variants IdempotenceRequiresAcksAll, IdempotenceRequiresRetries, TransactionalRequiresAcksAll, MissingTransactionVersionFeature, UnsupportedTransactionVersion { level: i16, }, UnsupportedApiVersion { api: &'static str, min_version: i16, broker_version: i16, }, NotTransactional, TopicHasNoPartitions { topic: String, }, MissingPartitionMetadata { topic: String, }, MetadataTimeout { topic: String, max_block_ms: u128, }, TransactionManagerUnavailable { operation: &'static str, }, TransactionalProducerNotInitialized { operation: &'static str, }, TransactionCoordinatorConnectionMissing, AttemptsExhausted { operation: &'static str, resource: String, attempts: usize, }, BatchFailed { topic: String, partition: i32, message: String, }, RecordTooLarge { size: usize, limit_name: &'static str, limit: usize, }, RequestTooLarge { size: usize, limit: usize, }, BufferExhausted { buffered: usize, required: usize, limit: usize, max_block_ms: u128, }, TransactionAbortRequired { operation: &'static str, message: String, }, TransactionFatal { operation: &'static str, message: String, }, RuntimeStoppedBefore { operation: &'static str, }, RuntimeStoppedDuring { operation: &'static str, }, Join(JoinError),
}
Errors raised by the producer API.

Variants



IdempotenceRequiresAcksAll

Idempotence was enabled without acks=-1.



IdempotenceRequiresRetries

Idempotence was enabled without retries.



TransactionalRequiresAcksAll

Transactions require all replicas to acknowledge records.



MissingTransactionVersionFeature

The broker did not report the transaction feature level.



UnsupportedTransactionVersion

The broker transaction feature level is too old.

Fields

level: i16

Broker feature level.



UnsupportedApiVersion

A broker API version is older than this client needs.

Fields

api: &'static str

API name.

min_version: i16

Minimum required API version.

broker_version: i16

Version advertised by the broker.



NotTransactional

The operation requires a configured transactional id.



TopicHasNoPartitions

Metadata reported no partitions for the topic.

Fields

topic: String

Topic name.



MissingPartitionMetadata

Metadata did not include partition data for a topic.

Fields

topic: String

Topic name.



MetadataTimeout

Metadata was not available before max_block elapsed.

Fields

topic: String

Topic name.

max_block_ms: u128

Configured max block in milliseconds.



TransactionManagerUnavailable

The transaction manager unexpectedly disappeared.

Fields

operation: &'static str

Operation that needed the transaction manager.



TransactionalProducerNotInitialized

A transactional producer id was needed but had not been initialized.

Fields

operation: &'static str

Operation that needed the producer id.



TransactionCoordinatorConnectionMissing

A coordinator connection was needed but had not been opened.



AttemptsExhausted

A producer coordinator request exhausted all attempts.

Fields

operation: &'static str

Operation that exhausted retries.

resource: String

Optional transactional id, group id, topic, or partition context.

attempts: usize

Number of attempts made.



BatchFailed

A produce batch failed before the broker accepted it.

Fields

topic: String

Topic name.

partition: i32

Partition number.

message: String

Failure detail.



RecordTooLarge

A record is too large for the configured producer limits.

Fields

size: usize

Estimated serialized record size.

limit_name: &'static str

Config limit name.

limit: usize

Configured limit.



RequestTooLarge

A Produce request is too large for the configured producer limits.

Fields

size: usize

Estimated serialized request size.

limit: usize

Configured limit.



BufferExhausted

The accumulator did not have room for a record before max_block elapsed.

Fields

buffered: usize

Current estimated queued bytes.

required: usize

Additional bytes needed for the record.

limit: usize

Configured buffer size.

max_block_ms: u128

Configured max block in milliseconds.



TransactionAbortRequired

A transactional operation failed and the open transaction must be aborted.

Fields

operation: &'static str

Operation that failed.

message: String

Failure detail.



TransactionFatal

A transactional operation failed and the producer is no longer usable.

Fields

operation: &'static str

Operation that failed.

message: String

Failure detail.



RuntimeStoppedBefore

The sender task stopped before the operation was sent.

Fields

operation: &'static str

Operation that was waiting to be sent.



RuntimeStoppedDuring

The sender task stopped while the operation was waiting for a reply.

Fields

operation: &'static str

Operation that was in flight.



Join(JoinError)

The sender task could not be joined.