ValidationError

Enum ValidationError 

pub enum ValidationError {
    EmptyTopicName {
        operation: &'static str,
    },
    MissingTopic {
        operation: &'static str,
    },
    NegativePartition {
        operation: &'static str,
        partition: i32,
    },
    EmptyResourceName {
        resource: &'static str,
    },
    InvalidAclResourceType {
        resource_type: String,
    },
    InvalidAclPatternType {
        pattern_type: String,
    },
    EmptyAclPrincipal,
    EmptyAclHost,
    InvalidAclOperation {
        operation: String,
    },
    InvalidAclPermissionType {
        permission_type: String,
    },
    EmptyConsumerGroupId,
    EmptyFeatureName,
}
Errors raised while validating public API inputs.

Variants



EmptyTopicName

A topic name was empty after trimming.

Fields

operation: &'static str

Operation validating the topic.



MissingTopic

A message did not provide a topic and no default topic was configured.

Fields

operation: &'static str

Operation validating the message.



NegativePartition

A partition was negative.

Fields

operation: &'static str

Operation validating the partition.

partition: i32

Requested partition.



EmptyResourceName

A resource name was empty after trimming.

Fields

resource: &'static str

Resource type being validated.



InvalidAclResourceType

An ACL resource type cannot be used in a concrete ACL binding.

Fields

resource_type: String

Invalid resource type.



InvalidAclPatternType

An ACL pattern type cannot be used in a concrete ACL binding.

Fields

pattern_type: String

Invalid pattern type.



EmptyAclPrincipal

An ACL principal was empty after trimming.



EmptyAclHost

An ACL host was empty after trimming.



InvalidAclOperation

An ACL operation cannot be used in a concrete ACL binding.

Fields

operation: String

Invalid ACL operation.



InvalidAclPermissionType

An ACL permission type cannot be used in a concrete ACL binding.

Fields

permission_type: String

Invalid permission type.



EmptyConsumerGroupId

A consumer group id was empty after trimming.



EmptyFeatureName

A finalized feature name was empty after trimming.