KafkaConsumer

Struct KafkaConsumer 

pub struct KafkaConsumer { /* private fields */ }
A Kafka group consumer with explicit polling and commits.

Implementations

Source

impl KafkaConsumer

pub async fn connect(config: ConsumerConfig) -> Result<Self>

Connects to Kafka and returns the client.

pub fn with_default_poll_timeout(self, timeout: Duration) -> Self

Sets default poll timeout and returns the updated value.

pub async fn subscribe(&self, topics: Vec<String>) -> Result<()>

Subscribe.

pub async fn subscribe_pattern( &self, pattern: SubscriptionPattern, ) -> Result<()>

Subscribe Pattern.

pub async fn subscribe_regex(&self, pattern: String) -> Result<()>

Subscribe Regex.

pub async fn unsubscribe(&self) -> Result<()>

Unsubscribe.

pub async fn poll(&self) -> Result<ConsumerRecords>

Polls Kafka for records.

pub async fn poll_for(&self, timeout: Duration) -> Result<ConsumerRecords>

Poll For.

pub async fn assign(&self, partitions: Vec<TopicPartition>) -> Result<()>

Assign.

pub async fn seek(&self, partition: TopicPartition, offset: i64) -> Result<()>

Seek.

pub async fn seek_to_beginning( &self, partitions: Vec<TopicPartition>, ) -> Result<()>

Seek To Beginning.

pub async fn seek_to_end(&self, partitions: Vec<TopicPartition>) -> Result<()>

Seek To End.

pub async fn seek_to_timestamp( &self, partitions: Vec<TopicPartitionTimestamp>, ) -> Result<()>

Seek To Timestamp.

pub async fn position(&self, partition: TopicPartition) -> Result<i64>

Position.

pub async fn pause(&self, partitions: Vec<TopicPartition>) -> Result<()>

Pause.

pub async fn resume(&self, partitions: Vec<TopicPartition>) -> Result<()>

Resume.

pub async fn group_metadata(&self) -> Result<ConsumerGroupMetadata>

Group Metadata.

pub async fn assignment(&self) -> Result<BTreeSet<TopicPartition>>

Assignment.

pub async fn committed( &self, partitions: Vec<TopicPartition>, ) -> Result<Vec<TopicPartitionOffset>>

Committed.

pub async fn beginning_offsets( &self, partitions: Vec<TopicPartition>, ) -> Result<Vec<TopicPartitionOffset>>

Beginning Offsets.

pub async fn end_offsets( &self, partitions: Vec<TopicPartition>, ) -> Result<Vec<TopicPartitionOffset>>

End Offsets.

pub async fn offsets_for_times( &self, partitions: Vec<TopicPartitionTimestamp>, ) -> Result<Vec<TopicPartitionOffsetAndTimestamp>>

Offsets For Times.

pub async fn partitions_for( &self, topic: String, ) -> Result<Vec<TopicPartitionInfo>>

Partitions For.

pub async fn list_topics(&self) -> Result<Vec<String>>

List Topics.

pub async fn commit(&self, records: &ConsumerRecords) -> Result<()>

Commit.

pub async fn commit_offsets(&self, offsets: Vec<CommitOffset>) -> Result<()>

Commit Offsets.

pub async fn wakeup(&self) -> Result<()>

Wakeup.

pub async fn shutdown(self) -> Result<()>

Shuts the client down and waits for in-flight work to finish.