LogDirDescription

Struct LogDirDescription 

pub struct LogDirDescription {
    pub log_dir: String,
    pub error_code: i16,
    pub total_bytes: Option<i64>,
    pub usable_bytes: Option<i64>,
    pub replicas: Vec<ReplicaLogDirDescription>,
}
One broker log directory.

Fields

log_dir: String

Absolute log directory path.

error_code: i16

Broker protocol error code for this log directory, if any.

total_bytes: Option<i64>

Total size of the filesystem containing this log dir when returned by Kafka.

usable_bytes: Option<i64>

Usable size of the filesystem containing this log dir when returned by Kafka.

replicas: Vec<ReplicaLogDirDescription>

Replica logs in this directory.