pub struct ShareConsumerOptions {
pub share_acquire_mode: ShareAcquireMode,
pub max_poll_records: i32,
pub acknowledgement_commit_callback: Option<AcknowledgementCommitCallback>,
}Expand description
Share Consumer Options.
Fields
Share Acquire Mode.
max_poll_records: i32Max Poll Records.
acknowledgement_commit_callback: Option<AcknowledgementCommitCallback>Acknowledgement Commit Callback.
Implementations
Sets share acquire mode and returns the updated value.
Sourcepub fn with_max_poll_records(self, max_poll_records: i32) -> Self
pub fn with_max_poll_records(self, max_poll_records: i32) -> Self
Sets max poll records and returns the updated value.
Sourcepub fn with_acknowledgement_commit_callback<F>(self, callback: F) -> Self
pub fn with_acknowledgement_commit_callback<F>(self, callback: F) -> Self
Sets acknowledgement commit callback and returns the updated value.