pub struct TlsConfig {
pub ca_cert_path: Option<PathBuf>,
pub client_cert_path: Option<PathBuf>,
pub client_key_path: Option<PathBuf>,
pub server_name: Option<String>,
}Expand description
Tls Config.
Fields
ca_cert_path: Option<PathBuf>Ca Cert Path.
client_cert_path: Option<PathBuf>Client Cert Path.
client_key_path: Option<PathBuf>Client Key Path.
server_name: Option<String>Server Name.
Implementations
Sourceimpl TlsConfig
impl TlsConfig
Sourcepub fn with_ca_cert_path(self, path: impl Into<PathBuf>) -> Self
pub fn with_ca_cert_path(self, path: impl Into<PathBuf>) -> Self
Sets ca cert path and returns the updated value.
Sourcepub fn with_client_cert_path(self, path: impl Into<PathBuf>) -> Self
pub fn with_client_cert_path(self, path: impl Into<PathBuf>) -> Self
Sets client cert path and returns the updated value.
Sourcepub fn with_client_key_path(self, path: impl Into<PathBuf>) -> Self
pub fn with_client_key_path(self, path: impl Into<PathBuf>) -> Self
Sets client key path and returns the updated value.
Sourcepub fn with_server_name(self, server_name: impl Into<String>) -> Self
pub fn with_server_name(self, server_name: impl Into<String>) -> Self
Sets server name and returns the updated value.